==============================================
Welcome to django-easyfilters's documentation!
==============================================

django-easyfilters provides a UI for filtering a Django QuerySet by clicking on
links. It is similar in some ways to ``list_filter`` and ``date_hierarchy`` in
Django's admin, but for use outside the admin. Importantly, it also includes
result counts for the choices, and it has a bigger emphasis on intelligent
display and things 'just working'.


Contents:

.. toctree::
   :maxdepth: 2

   install
   overview
   filterset
   filters
   develop


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

